import React from "react";
import { Card, CardContent } from "./card";
import { cn } from "@/lib/utils";
import { LucideIcon } from "lucide-react";

type TrendDirection = "up" | "down" | "neutral";

interface StatsCardProps {
  title: string;
  value: string | number;
  icon: LucideIcon;
  iconColor?: string;
  iconBgColor?: string;
  trend?: {
    value: string;
    direction: TrendDirection;
  };
  className?: string;
}

export function StatsCard({
  title,
  value,
  icon: Icon,
  iconColor = "text-primary",
  iconBgColor = "bg-blue-100",
  trend,
  className,
}: StatsCardProps) {
  const getTrendColor = (direction: TrendDirection) => {
    switch (direction) {
      case "up":
        return "text-success";
      case "down":
        return "text-destructive";
      default:
        return "text-muted-foreground";
    }
  };

  const getTrendIcon = (direction: TrendDirection) => {
    switch (direction) {
      case "up":
        return "↑";
      case "down":
        return "↓";
      default:
        return "→";
    }
  };

  return (
    <Card className={cn("shadow-sm border border-neutral-200", className)}>
      <CardContent className="p-4">
        <div className="flex items-center">
          <div className={cn("p-2 rounded-md", iconBgColor)}>
            <Icon className={cn("h-5 w-5", iconColor)} />
          </div>
          <div className="ml-4">
            <p className="text-sm font-medium text-neutral-600">{title}</p>
            <p className="text-2xl font-semibold text-neutral-800">{value}</p>
          </div>
        </div>
        
        {trend && (
          <div className={cn("mt-4 text-xs flex items-center", getTrendColor(trend.direction))}>
            <span className="mr-1">{getTrendIcon(trend.direction)}</span>
            <span>{trend.value}</span>
          </div>
        )}
      </CardContent>
    </Card>
  );
}
