/**
 * Incident type codes and definitions based on the emergency response system.
 * This mapping is used to categorize incidents properly throughout the application.
 */

export interface IncidentTypeDefinition {
  code: string;
  description: string;
  shortCode?: string;
  status?: string;
  category?: string;
}

// Mapping based on provided CSV data
export const INCIDENT_TYPE_CODES: IncidentTypeDefinition[] = [
  { code: '01', description: 'AFA Residential', shortCode: 'R', status: 'Yes', category: 'D' },
  { code: '02', description: 'AFA Commercial', shortCode: 'W', status: 'N/A', category: 'N' },
  { code: '04', description: 'AFA Domestic', shortCode: 'B' },
  { code: '05', description: 'Assist Other Agency', shortCode: 'G' },
  { code: '06', description: 'Chimney', shortCode: 'RDS' },
  { code: '08', description: 'Fire Domestic' },
  { code: '09', description: 'Fire Commercial' },
  { code: '10', description: 'Fire Residential' },
  { code: '11', description: 'Fire-Other' },
  { code: '12', description: 'Fire In Open' },
  { code: '14', description: 'Fuel Spill' },
  { code: 'OTHER', description: 'Gain Entry' },
  { code: 'OTB', description: 'Hazmat' },
  { code: 'LCK', description: 'Lock In/Out' },
  { code: 'MED', description: 'Medical' },
  { code: 'RTH', description: 'Rescue from Height' },
  { code: 'RCT', description: 'RTC Trapped' },
  { code: 'RWS', description: 'RTC Washdown/Scene Safety' },
  { code: 'SPS', description: 'Special service' },
  { code: 'STB', description: 'Standby' },
  { code: 'VFR', description: 'Vehicle Fire' },
];

/**
 * Get the incident type definition by code
 */
export function getIncidentTypeByCode(code: string): IncidentTypeDefinition | undefined {
  return INCIDENT_TYPE_CODES.find(type => type.code === code);
}

/**
 * Get the incident type definition by description
 */
export function getIncidentTypeByDescription(description: string): IncidentTypeDefinition | undefined {
  return INCIDENT_TYPE_CODES.find(type => 
    type.description.toLowerCase() === description.toLowerCase()
  );
}

/**
 * Get the incident type options for select dropdown
 */
export const INCIDENT_TYPE_OPTIONS = INCIDENT_TYPE_CODES
  .filter(type => type.description)
  .map(type => ({
    value: type.description,
    label: type.code ? `${type.description} (${type.code})` : type.description
  }));