import { 
  AlertCircle, 
  Flame, 
  Building, 
  Car, 
  Bell, 
  Home, 
  Briefcase, 
  Key, 
  HelpCircle, 
  Sparkles,
  Siren
} from "lucide-react";

export type IncidentTypeConfig = {
  label: string;
  icon: any;
  color: string;
  badge: string;
};

export const INCIDENT_TYPES: Record<string, IncidentTypeConfig> = {
  "Fire Domestic": {
    label: "Fire Domestic",
    icon: Flame,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  },
  "Fire Commercial": {
    label: "Fire Commercial",
    icon: Building,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  },
  "Fire In Open": {
    label: "Fire In Open",
    icon: Flame,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  },
  "RTC Trapped": {
    label: "RTC Trapped",
    icon: Car,
    color: "text-orange-500",
    badge: "bg-orange-100 text-orange-800"
  },
  "RTC Washdown/Scene Safety": {
    label: "RTC Washdown/Scene Safety",
    icon: Car,
    color: "text-orange-500",
    badge: "bg-orange-100 text-orange-800"
  },
  "AFA Commercial": {
    label: "AFA Commercial",
    icon: Bell,
    color: "text-blue-500",
    badge: "bg-blue-100 text-blue-800"
  },
  "AFA Residential": {
    label: "AFA Residential",
    icon: Bell,
    color: "text-blue-500",
    badge: "bg-blue-100 text-blue-800"
  },
  "Special service": {
    label: "Special Service",
    icon: Briefcase,
    color: "text-purple-500",
    badge: "bg-purple-100 text-purple-800"
  },
  "Special Service": {
    label: "Special Service",
    icon: Briefcase,
    color: "text-purple-500",
    badge: "bg-purple-100 text-purple-800"
  },
  "Gain Entry": {
    label: "Gain Entry",
    icon: Key,
    color: "text-yellow-500",
    badge: "bg-yellow-100 text-yellow-800"
  },
  "Lock In/Out": {
    label: "Lock In/Out",
    icon: Key,
    color: "text-yellow-500",
    badge: "bg-yellow-100 text-yellow-800"
  },
  "Assist Other Agency": {
    label: "Assist Other Agency",
    icon: HelpCircle,
    color: "text-indigo-500",
    badge: "bg-indigo-100 text-indigo-800"
  },
  "Chimney": {
    label: "Chimney",
    icon: Flame,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  },
  "Vehicle Fire": {
    label: "Vehicle Fire",
    icon: Car,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  },
  "Standby": {
    label: "Standby",
    icon: AlertCircle,
    color: "text-amber-500",
    badge: "bg-amber-100 text-amber-800"
  },
  "Rescue from Height": {
    label: "Rescue from Height",
    icon: Siren,
    color: "text-purple-500",
    badge: "bg-purple-100 text-purple-800"
  },
  "Fire-Other": {
    label: "Fire - Other",
    icon: Flame,
    color: "text-red-500",
    badge: "bg-red-100 text-red-800"
  }
};

export function getIncidentTypeConfig(type: string): IncidentTypeConfig {
  const normalizedType = type?.trim();
  if (!normalizedType) {
    return {
      label: "Unknown",
      icon: HelpCircle,
      color: "text-gray-500",
      badge: "bg-gray-100 text-gray-800"
    };
  }
  
  return INCIDENT_TYPES[normalizedType] || {
    label: normalizedType,
    icon: HelpCircle,
    color: "text-gray-500",
    badge: "bg-gray-100 text-gray-800"
  };
}

// Import the incident type codes from the new CSV file data
import { INCIDENT_TYPE_CODES } from './incident-type-codes';

// Create a combined options list from both sources
export const INCIDENT_TYPE_OPTIONS = [
  ...Object.keys(INCIDENT_TYPES).map(key => ({
    value: key,
    label: INCIDENT_TYPES[key].label
  })),
  // Add any unique incident types from the CSV that aren't already in our types
  ...INCIDENT_TYPE_CODES
    .filter(type => !INCIDENT_TYPES[type.description])
    .map(type => ({
      value: type.description,
      label: type.code ? `${type.description} (${type.code})` : type.description
    }))
];

export const STATUS_TYPES = {
  "completed": {
    label: "Completed",
    badge: "bg-green-100 text-green-800"
  },
  "pending": {
    label: "Pending Review",
    badge: "bg-yellow-100 text-yellow-800"
  },
  "in-progress": {
    label: "In Progress",
    badge: "bg-blue-100 text-blue-800"
  }
};

export function getIncidentStatus(incident: any): keyof typeof STATUS_TYPES {
  // Simple logic to determine status based on incident data
  if (incident.safetyCheck && !incident.safetyCheckComplete) {
    return "pending";
  }
  return "completed";
}

export const WATCH_OPTIONS = [
  { value: "White Watch", label: "White Watch" },
  { value: "Red Watch", label: "Red Watch" },
  { value: "Green Watch", label: "Green Watch" },
  { value: "Blue Watch", label: "Blue Watch" },
  { value: "RDS", label: "RDS" }
];
