import xlsx from 'xlsx';
import fs from 'fs';
import path from 'path';
import { fileURLToPath } from 'url';

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);

// Path to the Excel file
const excelFilePath = path.join(__dirname, '../attached_assets/New Management Sheet 2025.xlsx');

// Path for the output CSV file
const csvFilePath = path.join(__dirname, '../data/incidents.csv');

// Ensure the data directory exists
if (!fs.existsSync(path.dirname(csvFilePath))) {
  fs.mkdirSync(path.dirname(csvFilePath), { recursive: true });
}

try {
  // Read the Excel file
  const workbook = xlsx.readFile(excelFilePath);
  
  // Get the first sheet
  const sheetName = workbook.SheetNames[0];
  const worksheet = workbook.Sheets[sheetName];
  
  // Convert the sheet to CSV
  const csvContent = xlsx.utils.sheet_to_csv(worksheet);
  
  // Write the CSV content to a file
  fs.writeFileSync(csvFilePath, csvContent);
  
  console.log(`Excel file successfully converted to CSV at ${csvFilePath}`);
} catch (error) {
  console.error('Error converting Excel file to CSV:', error);
}